import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0

Page {
    id: root
    tools: mainTools

    //! Page title contains label with application name.
    PageHeader {
        id: headerholder
        title: qsTr("Loan Repayments Calculator")
    }

    Flickable {
            anchors.top: headerholder.bottom
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.leftMargin: 10
            anchors.topMargin: 10
            contentWidth: entryCol.width
            contentHeight: entryCol.height
            flickableDirection: Flickable.VerticalFlick
            clip: true

    Column {
        id: entryCol
        width: root.width - 20
        spacing: 12

        Row {
            width: parent.width
            spacing: 10
            Label {
                text: qsTr("Amount ($)")
                width: 150
                anchors.verticalCenter: parent.verticalCenter
            }
            TextField {
                id: txtAmount
                objectName: "txtAmount"
                placeholderText: qsTr("$")
                width: parent.width - 160
                inputMethodHints: Qt.ImhFormattedNumbersOnly
                onTextChanged: engine.computeRepayments(butInterestOnly.checked)
            }
        }
        Row {
            width: parent.width
            spacing: 10
            Label {
                text: qsTr("Rate (%)")
                width: 150
                anchors.verticalCenter: parent.verticalCenter
            }
            TextField {
                id: txtInterest
                objectName: "txtInterest"
                placeholderText: qsTr("%")
                width: parent.width - 160
                inputMethodHints: Qt.ImhFormattedNumbersOnly
                onTextChanged: engine.computeRepayments(butInterestOnly.checked)
            }
        }
        Row {
            width: parent.width
            spacing: 10
            Label {
                text: qsTr("Period (Years)")
                width: 150
                anchors.verticalCenter: parent.verticalCenter
            }
            TextField {
                id: txtYears
                objectName: "txtYears"
                placeholderText: qsTr("Years")
                width: parent.width - 160
                inputMethodHints: Qt.ImhFormattedNumbersOnly
                onTextChanged: engine.computeRepayments(butInterestOnly.checked)
            }
        }
        RadioButton {
            id: butBoth
            text: qsTr("Principal & Interest")
            checked: true
            onClicked: { if (checked) { butInterestOnly.checked = false; } engine.computeRepayments(butInterestOnly.checked); }
        }
        RadioButton {
            id: butInterestOnly
            text: qsTr("Interest Only")
            checked: false
            onClicked: { if (checked) { butBoth.checked = false; } engine.computeRepayments(butInterestOnly.checked); }
        }
        Rectangle {
            width: parent.width
            height: 1
            color: "darkgray"
        }
        Label {
            anchors.topMargin: 30
            text: qsTr("ESTIMATED REPAYMENT")
        }
        Row {
            width: parent.width
            spacing: 10
            Label {
                text: "Monthly"
                width: 150
                anchors.verticalCenter: parent.verticalCenter
            }
            TextField {
                id: txtMonthly
                objectName:"txtMonthly"
                readOnly: true
                width: parent.width - 160
            }
        }
        Row {
            width: parent.width
            spacing: 10
            Label {
                text: qsTr("Fortnightly")
                width: 150
                anchors.verticalCenter: parent.verticalCenter
            }
            TextField {
                id: txtFortnightly
                objectName: "txtFortnightly"
                readOnly: true
                width: parent.width - 160
            }
        }
        Row {
            width: parent.width
            spacing: 10
            Label {
                text: qsTr("Weekly")
                width: 150
                anchors.verticalCenter: parent.verticalCenter
            }
            TextField {
                id: txtWeekly
                objectName: "txtWeekly"
                readOnly: true
                width: parent.width - 160
            }
        }
    }
    }

    ToolBarLayout {
        id: mainTools
        visible: true
        //ToolIcon {
        //    id: butRefresh
        //    visible: false
        //    platformIconId: "toolbar-refresh"
        //    anchors.left: (parent === undefined) ? undefined : parent.left
        //    onClicked: { engine.computeRepayments(butInterestOnly.checked); butRefresh.visible = false; }
        //}
        ToolIcon {
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (myMenu.status === DialogStatus.Closed) ? myMenu.open() : myMenu.close()
        }
    }

    Menu {
        id: myMenu
        visualParent: pageStack
        MenuLayout {
            MenuItem { text: qsTr("About"); onClicked: appWindow.openFile("About.qml"); }
        }
    }
}
